pub enum ToneMappingMethod {
Rec2408(GainHdrMetadata),
Filmic,
Aces,
Reinhard,
ExtendedReinhard,
ReinhardJodie,
Clamp,
FilmicSpline(FilmicSplineParameters),
}Expand description
Defines a tone mapping method.
All tone mappers are local unless other is stated.
See this blog post for more details on many of the supported tone mapping methods.
Variants
Rec2408(GainHdrMetadata)
ITU-R broadcasting TV recommendation 2408
Filmic
The ‘Uncharted 2’ filmic tone mapping method.
Aces
The Academy Color Encoding System filmic tone mapping method.
Reinhard
Erik Reinhard’s tone mapper from the paper “Photographic tone reproduction for digital images”.
ExtendedReinhard
Same as Reinhard but scales the output to the full dynamic
range of the image.
ReinhardJodie
A variation of Reinhard that uses mixes color-based- with
luminance-based tone mapping.
Clamp
Simply clamp the output to the available dynamic range.
FilmicSpline(FilmicSplineParameters)
This is a parameterized curve based on the Blender Filmic tone mapping method similar to the module found in Ansel/Darktable.